/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.hillenbrand.demo;

import de.hillenbrand.jreqtools.*;
import de.hillenbrand.swing.*;
import de.hillenbrand.system.*;
import de.hillenbrand.util.*;


public class GenericRequester {
	
	
	public static void main(String [] args)  {
		// init the UI System
		UIPreferences.init();
		
		final String [] choices = new String [] { "One", "Two", "Three", "Four", "Five" };
		
		// make up some types
		final GenericOkCancelRequester.TypeConfig [] types = {
		
			new GenericOkCancelRequester.Tab("Strings & Text"),
			new GenericOkCancelRequester.TypeConfig("String:"				, GenericOkCancelRequester.TYPE_STRING				, "This is a default string."),
			new GenericOkCancelRequester.TypeConfig("Password:"			, GenericOkCancelRequester.TYPE_PASSWORD			, new char [] { 's', 'e', 'c', 'r', 'e', 't' }),
			new GenericOkCancelRequester.TypeConfig("Text:"					, GenericOkCancelRequester.TYPE_TEXT					, "This is a text.\nIt has multiple lines."),
		
			new GenericOkCancelRequester.Tab("Numbers"),
			new GenericOkCancelRequester.TypeConfig("Byte:"					, GenericOkCancelRequester.TYPE_BYTE					, new Byte(Byte.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Short:"				, GenericOkCancelRequester.TYPE_SHORT					, new Short(Short.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Integer:"				, GenericOkCancelRequester.TYPE_INTEGER				, new Integer(Integer.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Long:"					, GenericOkCancelRequester.TYPE_LONG					, new Long(Long.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Float:"					, GenericOkCancelRequester.TYPE_FLOAT					, new Float(Float.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Double:"				, GenericOkCancelRequester.TYPE_DOUBLE				, new Double(Double.MAX_VALUE)),
			
			new GenericOkCancelRequester.Tab("Choices & Lists"),
			new GenericOkCancelRequester.TypeConfig("Choice:"				, GenericOkCancelRequester.TYPE_CHOICE				, choices, new Integer(0)),
			new GenericOkCancelRequester.TypeConfig("Editable Choice:"		, GenericOkCancelRequester.TYPE_EDITABLE_CHOICE	, choices, new Integer(1)),
			new GenericOkCancelRequester.TypeConfig("Single Selection:"	, GenericOkCancelRequester.TYPE_SINGLE_SELECTION	, choices, new Integer(2)),
			new GenericOkCancelRequester.TypeConfig("Multi Selection:"		, GenericOkCancelRequester.TYPE_MULTI_SELECTION	, choices, 
				new Integer [] { new Integer(1), new Integer(3), new Integer(4) }),
			
			new GenericOkCancelRequester.Tab("Editable List"),
			new GenericOkCancelRequester.TypeConfig("Editable List:"		, GenericOkCancelRequester.TYPE_EDITABLE_LIST		, choices),
		};
		
		// create and open the test frame
		while (true)
			{
			final GenericOkCancelRequester req = new GenericOkCancelRequester("Title", "Please enter all data:", types);
			if (req.request( (HFrame) null) == GenericOkCancelRequester.OK) 
				{
				for (int i=0; i<types.length; ++i) System.out.println("Result["+i+"]="+req.getResult(i));
				System.exit(0);
				}
			}
	}

}
